@@ -1,4 +1,10 @@
-#![allow(clippy::undocumented_unsafe_blocks, clippy::wildcard_imports)]
+#![allow(
+    clippy::alloc_instead_of_core,
+    clippy::std_instead_of_alloc,
+    clippy::std_instead_of_core,
+    clippy::undocumented_unsafe_blocks,
+    clippy::wildcard_imports
+)]
 
 #[macro_use]
 pub(crate) mod helper;
@@ -10,6 +16,7 @@ use super::*;
 
 test_atomic_bool_pub!();
 test_atomic_ptr_pub!();
+
 test_atomic_int_pub!(isize);
 test_atomic_int_pub!(usize);
 test_atomic_int_pub!(i8);
@@ -22,6 +29,7 @@ test_atomic_int_pub!(i64);
 test_atomic_int_pub!(u64);
 test_atomic_int_pub!(i128);
 test_atomic_int_pub!(u128);
+
 #[cfg(feature = "float")]
 test_atomic_float_pub!(f32);
 #[cfg(feature = "float")]
@@ -41,7 +49,13 @@ extern "C" {
     fn _atomic_u32_ffi_safety(_: AtomicU32);
     fn _atomic_i64_ffi_safety(_: AtomicI64);
     fn _atomic_u64_ffi_safety(_: AtomicU64);
-    // TODO: https://github.com/rust-lang/unsafe-code-guidelines/issues/119
+    // TODO: 128-bit integers are not FFI safe
+    // https://github.com/rust-lang/unsafe-code-guidelines/issues/119
+    // https://github.com/rust-lang/rust/issues/54341
     // fn _atomic_i128_ffi_safety(_: AtomicI128);
     // fn _atomic_u128_ffi_safety(_: AtomicU128);
+    #[cfg(feature = "float")]
+    fn _atomic_f32_ffi_safety(_: AtomicF32);
+    #[cfg(feature = "float")]
+    fn _atomic_f64_ffi_safety(_: AtomicF64);
 }
